This crate contains mocks for the aya crate.
These are very crude implementations that mimic the signatures of many Aya structs/functions. They can be used as drop in replacements.
This approach is very dirty and should be used sparingly. Better mocks would be welcome. Hopefully in the future this may be something offered by Aya: https://github.com/aya-rs/aya/issues/999